﻿using Syncfusion.DataSource;
using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Text;
using Xamarin.Forms;
using static SfListViewSample.LoadMoreViewModel;

namespace SfListViewSample
{
    public class SfListViewSortingFilteringBehavior : Behavior<ContentPage>
    {
        #region Fields

        private SfListView ListView;
        private LoadMoreViewModel sortingFilteringViewModel;
        private SearchBar searchBar = null;
        private Grid seachbar_Grid;

        #endregion

        #region Overrides
        protected override void OnAttachedTo(ContentPage bindable)
        {
            ListView = bindable.FindByName<SfListView>("listView");
            sortingFilteringViewModel = new LoadMoreViewModel();
            ListView.BindingContext = sortingFilteringViewModel;
            ListView.ItemsSource = sortingFilteringViewModel.Products;

            seachbar_Grid = bindable.FindByName<Grid>("seachbar_Grid");
            if (Device.RuntimePlatform == Device.UWP)
                seachbar_Grid.Padding = new Thickness(5, 5, 0, 5);

            searchBar = bindable.FindByName<SearchBar>("filterText");
            searchBar.TextChanged += SearchBar_TextChanged;
            base.OnAttachedTo(bindable);
        }

        protected override void OnDetachingFrom(ContentPage bindable)
        {
            ListView = null;
            searchBar = null;
            searchBar.TextChanged -= SearchBar_TextChanged;
            base.OnDetachingFrom(bindable);
        }

        #endregion

        #region Events
        private void SearchBar_TextChanged(object sender, TextChangedEventArgs e)
        {
            searchBar = (sender as SearchBar);
            if (ListView.DataSource != null)
            {
                ListView.DataSource.Filter = FilterContacts;
                ListView.DataSource.RefreshFilter();
            }
            ListView.RefreshView();
        }

        #endregion

        #region Methods
        private bool FilterContacts(object obj)
        {
            if (searchBar == null || searchBar.Text == null)
                return true;

            var taskInfo = obj as Product;
            return (taskInfo.Name.ToLower().Contains(searchBar.Text.ToLower()));
        }

        #endregion
    }

}
